from data_fetcher import fetch_historical_data, fetch_realtime_data
from strategy import generate_signals
from backtester import execute_backtest, analyze_performance
from visualizer import plot_performance
from notifier import send_email
import time

def main():
    # 사용하고자 하는 주식과 기간을 지정
    symbol = '005930'  # 삼성전자 예시 (종목 코드)
    market_code = 'J'  # KOSPI: J, KOSDAQ: K
    start_date = '2020-01-01'  # 데이터 수집 시작 날짜
    end_date = '2023-01-01'  # 데이터 수집 종료 날짜
    
    try:
        # 초기 데이터 수집 및 백테스트
        data = fetch_historical_data(symbol, market_code, start_date, end_date)
        signals = generate_signals(data)
        portfolio = execute_backtest(signals)
        performance_metrics = analyze_performance(portfolio)
        plot_performance(portfolio, signals)
        print("Initial Backtest Performance Metrics:", performance_metrics)
        
        # 실시간 데이터 수집 및 거래
        while True:
            realtime_data = fetch_realtime_data(symbol, market_code)
            signals = generate_signals(realtime_data)
            portfolio = execute_backtest(signals)
            performance_metrics = analyze_performance(portfolio)
            print("Real-time Performance Metrics:", performance_metrics)
            
            # 알림 예시 (조건부로 알림 전송)
            if performance_metrics['Total Return'] < -0.05:  # 예시 조건
                send_email(
                    subject="Alert: Significant Loss Detected",
                    body=f"Total Return: {performance_metrics['Total Return']:.2f}",
                    to_email="your_email@example.com",
                    from_email="from_email@example.com",
                    smtp_server="smtp.example.com",
                    smtp_port=587,
                    smtp_user="smtp_user",
                    smtp_password="smtp_password"
                )

            time.sleep(60)  # 1분마다 데이터 갱신 (적절히 조정)

    except Exception as e:
        print(f"An error occurred: {e}")

if __name__ == "__main__":
    main()
