import pandas as pd
import numpy as np
import talib as ta

def generate_signals(data, short_window=50, long_window=200, rsi_period=14, 
                     macd_fast=12, macd_slow=26, macd_signal=9, 
                     stoch_k=14, stoch_d=3):
    signals = pd.DataFrame(index=data.index)
    signals['price'] = data['stck_clpr'].astype(float)

    # 이동 평균 계산
    signals['short_mavg'] = ta.SMA(data['stck_clpr'], timeperiod=short_window)
    signals['long_mavg'] = ta.SMA(data['stck_clpr'], timeperiod=long_window)

    # 볼린저 밴드 계산
    signals['upper_band'], signals['middle_band'], signals['lower_band'] = ta.BBANDS(data['stck_clpr'], timeperiod=20, nbdevup=2, nbdevdn=2)

    # RSI 계산
    signals['rsi'] = ta.RSI(data['stck_clpr'], timeperiod=rsi_period)

    # MACD 계산
    signals['macd'], signals['macd_signal'], _ = ta.MACD(data['stck_clpr'], fastperiod=macd_fast, slowperiod=macd_slow, signalperiod=macd_signal)

    # Stochastic Oscillator 계산
    signals['slowk'], signals['slowd'] = ta.STOCH(data['stck_hgpr'], data['stck_lwpr'], data['stck_clpr'], fastk_period=stoch_k, slowk_period=stoch_d, slowd_period=stoch_d)

    # 거래량 평균 계산
    signals['volume_avg'] = data['stck_prdy_vrss_vol'].rolling(window=20, min_periods=1).mean()

    # 매수 신호 생성
    signals['buy_signal'] = np.where(
        (signals['short_mavg'] > signals['long_mavg']) &
        (signals['rsi'] < 30) &
        (signals['macd'] > signals['macd_signal']) &
        (signals['slowk'] < 20) &
        (signals['slowd'] < 20) &
        (data['stck_prdy_vrss_vol'] > signals['volume_avg']), 1.0, 0.0
    )

    # 매도 신호 생성
    signals['sell_signal'] = np.where(
        (signals['short_mavg'] < signals['long_mavg']) &
        (signals['rsi'] > 70) &
        (signals['macd'] < signals['macd_signal']) &
        (signals['slowk'] > 80) &
        (signals['slowd'] > 80) &
        (data['stck_prdy_vrss_vol'] > signals['volume_avg']), -1.0, 0.0
    )

    # 최종 신호 생성
    signals['signal'] = signals['buy_signal'] + signals['sell_signal']
    signals['position'] = signals['signal'].diff()

    return signals
