import requests

def get_access_token(config):
    url = f"{config['api_config']['access_token']['domain']}{config['api_config']['access_token']['url']}"
    headers = {
        'content-type': config['api_config']['access_token']['headers']['content-type']
    }
    body = {
        'grant_type': config['api_config']['access_token']['body']['grant_type'],
        'appkey': config['api_config']['access_token']['body']['appkey'],
        'appsecret': config['api_config']['access_token']['body']['appsecret']
    }
    response = requests.post(url, headers=headers, json=body)
    if response.status_code == 200:
        return response.json().get('access_token')
    else:
        raise Exception(f"Failed to get access token: {response.status_code}, {response.text}")

def fetch_balance(config, access_token, cano, acnt_prdt_cd):
    headers = {
        'content-type': config['api_config']['stock_balance']['headers']['content-type'],
        'authorization': f"Bearer {access_token}",
        'appkey': config['api_config']['stock_balance']['headers']['appkey'],
        'appsecret': config['api_config']['stock_balance']['headers']['appsecret'],
        'tr_id': config['api_config']['stock_balance']['headers']['tr_id']
    }
    params = {
        'CANO': cano,
        'ACNT_PRDT_CD': acnt_prdt_cd,
        'AFHR_FLPR_YN': config['api_config']['stock_balance']['query_params']['AFHR_FLPR_YN'],
        'OFL_YN': config['api_config']['stock_balance']['query_params']['OFL_YN'],
        'INQR_DVSN': config['api_config']['stock_balance']['query_params']['INQR_DVSN'],
        'UNPR_DVSN': config['api_config']['stock_balance']['query_params']['UNPR_DVSN'],
        'FUND_STTL_ICLD_YN': config['api_config']['stock_balance']['query_params']['FUND_STTL_ICLD_YN'],
        'FNCG_AMT_AUTO_RDPT_YN': config['api_config']['stock_balance']['query_params']['FNCG_AMT_AUTO_RDPT_YN'],
        'PRCS_DVSN': config['api_config']['stock_balance']['query_params']['PRCS_DVSN'],
        'COST_ICLD_YN': config['api_config']['stock_balance']['query_params']['COST_ICLD_YN'],
        'CTX_AREA_FK100': config['api_config']['stock_balance']['query_params']['CTX_AREA_FK100'],
        'CTX_AREA_NK100': config['api_config']['stock_balance']['query_params']['CTX_AREA_NK100']
    }

    response = requests.get(
        f"{config['api_config']['stock_balance']['domain']}{config['api_config']['stock_balance']['url']}",
        headers=headers,
        params=params
    )

    if response.status_code == 200:
        return response.json()
    else:
        return {'error': response.status_code, 'message': response.text}

def sell_all_holdings(config, access_token):
    # Implement the logic to sell all holdings here.
    # For now, we'll mock the response.
    return "All holdings have been sold successfully."

def cancel_all_orders(config, access_token, cancel_all):
    if cancel_all:
        # Implement the logic to cancel all orders here.
        # For now, we'll mock the response.
        return "All orders have been cancelled successfully."
    else:
        # Implement the logic to cancel specific orders here.
        # For now, we'll mock the response.
        return "Selected orders have been cancelled successfully."
